@@ -144,8 +144,11 @@ class CHAR(Variable):
                 raise StringCharConfusingError(ch)
             try:
                 self.val = ch.encode(DEFAULT_CHARSET)[0]
-            except UnicodeDecodeError:
-                raise InvalidASCIICharError(ch)
+            except UnicodeEncodeError:
+                self.val = 'Invalid'
+            finally:
+                if self.val == 'Invalid':
+                    raise InvalidASCIICharError(ch)
         elif isinstance(ch, int):
             self.val = ch
         elif isinstance(ch, bytes):
@@ -166,8 +169,11 @@ class CHAR(Variable):
                 raise StringCharConfusingError(char)
             try:
                 self.val = char.encode(DEFAULT_CHARSET)[0]
-            except UnicodeDecodeError:
-                raise InvalidASCIICharError(char)
+            except UnicodeEncodeError:
+                self.val = 'Invalid'
+            finally:
+                if self.val == 'Invalid':
+                    raise InvalidASCIICharError(char)
         elif isinstance(char, int):
             if 0 <= char < 128:
                 self.val = char
