@@ -15,22 +15,24 @@ class IStream:
         self.buf = ''
 
         def Read(var):
+            while not self.buf:
+                tmp = stdin.readline()
+                if not tmp:
+                    raise EOFError
+                self.buf += tmp[:-1]
+                
             if var.type == 'char':
                 var.load(self.buf)
                 self.buf = self.buf[1:]
-            p = 0
-            while not self.buf:
-                self.buf += stdin.readline()[:-1]
-                if not self.buf:
-                    raise EOFError
-            while self.buf[p] == ' ':
-                p += 1
-            if ' ' in self.buf:
-                pp = self.buf.index(' ', p)
+                return
+                
+            self.buf = self.buf.strip()
+            pp = self.buf.find(' ')
+            if pp != -1:
                 var.load(self.buf[p:pp])
                 self.buf = self.buf[pp + 1:]
             elif self.buf:
-                var.load(self.buf[p:])
+                var.load(self.buf)
                 self.buf = ''
 
         self.R = Read
